@@ -39,6 +39,8 @@ def main():
     parser.add_argument('-o', '--output-filename', dest='output_filename', help='specify the name of the generated control file', default='')
     parser.add_argument('-a', '--averaging-scan-limit', type=int, dest='averaging_scan_limit', help='limit the number of scans used in averaging, use 0 to disable, default=10', default=10)
     parser.add_argument('-t', '--toggle-run-info', action='store_false', dest='toggle_dump_info', help='do not append control file with information about how this program was called', default=True)
+    parser.add_argument('-x', '--nchannel-discard-threshold', type=int, dest='nchannel_discard_threshold', help='specify number of channels allowed to be flagged before discarding this entire scan', default=5)
+    parser.add_argument('-y', '--channel-discard-tolerance', type=float, dest='channel_discard_tolerance', help='allowable channel phase error (deg) before it is flagged', default=15.0)
 
     args = parser.parse_args()
 
@@ -156,6 +158,8 @@ def main():
     ffres2pcp_conf.start_scan_limit = start_scan_limit
     ffres2pcp_conf.stop_scan_limit = stop_scan_limit
     ffres2pcp_conf.use_progress_ticker = args.use_progress_ticker
+    ffres2pcp_conf.nchannel_discard_threshold = args.nchannel_discard_threshold
+    ffres2pcp_conf.channel_discard_tolerance = args.channel_discard_tolerance
 
     #now generate the new control file name
     ffres2pcp_output_control_filename = ''
