@@ -2,13 +2,12 @@
 #define T230_VERSION 0
 
 #include "mk4_typedefs.h"
-#include <complex.h>
+#include "hops_complex.h"
                                         /* Set this to current version, */
                                         /* defined to be same as app struct */
 #define type_230_v0 type_230
 
-
-struct type_230 
+struct type_230
     {
     char            record_id[3];       /* Standard 3-digit id */
     char            version_no[2];      /* Standard 2-digit version # */
@@ -20,7 +19,7 @@ struct type_230
     int             ap;                 /* AP number, refer to 206 */
     float           lsbweight;          /* fraction of AP represented */
     float           usbweight;          /* fraction of AP represented */
-    complex         xpower[1];          /* Array of spectrum values */
+    hops_scomplex    xpower[1];          /* Array of spectrum values */
     };
 
 #endif
