@@ -8,7 +8,7 @@
 /************************************************/
 #include <stdio.h>
 #include <math.h>
-#include <complex.h>
+#include "hops_complex.h"
 #include <fftw3.h>
 #include "mk4_data.h"
 #include "param_struct.h"
@@ -16,10 +16,10 @@
 
 delay_rate (struct type_pass *pass,
             int fr,
-            complex rate_spectrum[MAXAP])
+            hops_complex rate_spectrum[MAXAP])
     {
-    complex apval, a;
-    complex fringe_spect[MAXAP*2], X[MAXAP*2];
+    hops_complex apval, a;
+    hops_complex fringe_spect[MAXAP*2], X[MAXAP*2];
     int fl, L, ap, np, i, j, l_int, l_int2, size;
     static int fft_size = 0;
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L, 1:R
@@ -31,9 +31,9 @@ delay_rate (struct type_pass *pass,
     static fftw_plan fftplan;
 
     pd = pass->pass_data + fr;
-    
+
     np = status.drsp_size;              /* np = # of ap's in FFT < MAXAP */
-    
+
     size = np * 4;                      /* This is size of FFT */
                                         /* Smaller delay rate spectrum option */
     if (size > MAXAP*2) size = MAXAP*2;
@@ -47,7 +47,7 @@ delay_rate (struct type_pass *pass,
         }
 
                                         /* Fill data array */
-    for (i = 0; i < size; i++) 
+    for (i = 0; i < size; i++)
         X[i] = 0.0;
     for (ap = 0; ap < pass->num_ap; ap++)
         {
@@ -62,7 +62,7 @@ delay_rate (struct type_pass *pass,
         if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) frac /= 2.0;
         X[ap] = apval * frac;
         }
-     
+
     fftw_execute (fftplan);
 
     for (i = 0; i < size; i++)
@@ -71,7 +71,7 @@ delay_rate (struct type_pass *pass,
         if (j < 0) j += size;
         fringe_spect[i] = X[j];
         }
-        
+
     b = (pass->pass_data[fr].frequency / param.ref_freq) * size / np;
 /*              / pass->pass_data[0].frequency) * size / np;  */
 
@@ -87,6 +87,6 @@ delay_rate (struct type_pass *pass,
         if (l_int2 > (size-1)) l_int2 = size - 1;
         rate_spectrum[L] = fringe_spect[l_int] * (1.0 - l_fp + l_int)
                          + fringe_spect[l_int2] * (l_fp - l_int);
-        msg("fr %d cabs(rate_spectrum[%d]) %f", -3, fr, L, cabs (rate_spectrum[L]));
+        //msg("fr %d cabs(rate_spectrum[%d]) %f", -3, fr, L, cabs (rate_spectrum[L]));
         }
      }
