@@ -18,9 +18,7 @@
 #include <complex.h>
 #include "mk4_data.h"
 
-FFT1 (In, NN, ISign,Out,rev)    
-complex In[MAXMAX*2], Out[MAXMAX*2];
-int NN,ISign,rev;
+FFT1 (complex In[MAXMAX*2], int NN, int ISign, complex Out[MAXMAX*2], int rev)    
     {
     double wr,wi,wpr,wpi,wtemp,theta,tempr,tempi,Data[MAXMAX*8 + 1];
     int i,j,n,istep,mmax,m;
