@@ -13,12 +13,6 @@
 #include <string.h>
 #include <ctype.h>
 
-static char fchars[64] =
-	{'a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p',
-     'q','r','s','t','u','v','w','x','y','z','A','B','C','D','E','F',
-     'G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V',
-     'W','X','Y','Z','0','1','2','3','4','5','6','7','8','9','$','%'};
-
  /* string contains conditioned input from control file */
 int lex (char* input_string)
     {
@@ -322,8 +316,10 @@ char *next_token;
    return (validity);
    }
    
-
-int fcode(char c)
+/*
+// this was commented out at some point and
+// the common routine is found in parser.c
+// // int fcode(char c)
 	{
 	int i;
 //	char fchars[64];
@@ -343,3 +339,4 @@ char get_fchar_by_index(int i)
 			return '\0';
 		}
 	}
+*/
