@@ -241,6 +241,12 @@ int *npass)
                         msg("corel freq code %c overwrite for freq %d",1, corel[j].freq_code,j);
                         break;
                         }
+                    else
+                        {
+                        double diff = fabs(corel[j].frequency - p->control.chid_rf[k]);
+                        if (diff < 0.1) msg("corel freq code %c miss: |%f - %f| = %f", 1,
+                            p->control.chid[k], corel[j].frequency, p->control.chid_rf[k], diff);
+                        }
                     }
             else
                 corel[j].freq_code = p->control.chid[j];
