@@ -7,7 +7,7 @@
 *                                                                    *
 *  92.8.26   rjc First written                                       *
 *  94.11.21  rjc Put ph. cal phases into offset array for all 3 modes*
-*  2009.8.27 rjc Allow pcal freqs to be entered as tone #'s          *  
+*  2009.8.27 rjc Allow pcal freqs to be entered as tone #'s          *
 *  2010.2.3  rjc consolidate remote and reference code into 1 loop   *
 *********************************************************************/
 #include "mk4_data.h"
@@ -18,11 +18,8 @@
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
-#include <complex.h>
-
-extern void   account (char *);
-extern void   msg (char *, int, ...);
-extern int fcode(char c);
+#include "hops_complex.h"
+#include "ff_misc_if.h"
 
 int precorrect (struct scan_struct* ovex, struct type_pass* pass)
     {
@@ -40,13 +37,13 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
     param.ref_freq = (pass->control.ref_freq == NULLFLOAT)?
                      pass->pass_data[0].frequency :
                      pass->control.ref_freq;
-                                         
+
     param.cor_limit = 16000.0;     /* Initialize large number threshold */
     param.use_sample_cnts = pass->control.use_samples;
                                     // get interpolation method for this pass
     param.interpol = pass->control.interpolator;
                                     // calculate offsets of windows due to position offsets
-                            
+
     // delay_offset = (pass->control.ra_offset  * rbase->t2600.u_obsfreq
     //               + pass->control.dec_offset * rbase->t2600.v_obsfreq) * 1e-3;
     //
@@ -55,7 +52,7 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
 
     delay_offset = 0.0;             // for now, just force 0 offset  rjc 99.8.13
     rate_offset = 0.0;
-    
+
     param.ion_pts = pass->control.ion_npts;
     param.mbd_anchor = pass->control.mbd_anchor;
     param.est_pc_manual = pass->control.est_pc_manual;
@@ -66,14 +63,18 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
         param.win_mb[i] = pass->control.mb_window[i] + delay_offset;
         param.win_dr[i] = pass->control.dr_window[i] + rate_offset;
         param.passband[i] = pass->control.passband[i];
+        param.avxpzoom[i] = pass->control.avxpzoom[i];
+        param.avxplopt[i] = pass->control.avxplopt[i];
                                     // ionosphere window is about differential a priori
                                     // collapses if only 1 pt (i.e. no search)
         param.win_ion[i] = (param.ion_pts > 1) ?
             pass->control.ion_window[i] : 0.0;
-        param.win_ion[i] += (pass->control.ionosphere.rem == NULLFLOAT) ? 
+        param.win_ion[i] += (pass->control.ionosphere.rem == NULLFLOAT) ?
                            0.0 : pass->control.ionosphere.rem;
-        param.win_ion[i] -= (pass->control.ionosphere.ref == NULLFLOAT) ? 
+        param.win_ion[i] -= (pass->control.ionosphere.ref == NULLFLOAT) ?
                            0.0 : pass->control.ionosphere.ref;
+        
+        param.mount_type[i] = pass->control.mount_type[i];
         }
     param.nnotches = pass->control.nnotches;
     for (j=0; j<pass->control.nnotches; j++)
@@ -88,7 +89,7 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
     param.pc_mode[1] = pass->control.pc_mode.rem;
     param.pc_period[0] = pass->control.pc_period.ref;
     param.pc_period[1] = pass->control.pc_period.rem;
-   
+
     status.lsb_phoff[0] = pass->control.lsb_offset.ref * conrad;
     status.lsb_phoff[1] = pass->control.lsb_offset.rem * conrad;
 
@@ -102,14 +103,14 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
         {
         n = param.ov_bline[stn];
         param.pcal_spacing[stn] = ovex->st[n].channels[0].pcal_spacing;
-        
-        for (fr = 0; fr < pass->nfreq; fr++)  
+
+        for (fr = 0; fr < pass->nfreq; fr++)
             {
-            j = fcode(pass->pass_data[fr].freq_code);
+            j = fcode(pass->pass_data[fr].freq_code, pass->control.chid);
             chind = pass->pass_data[fr].ch_idx[stn];
 
                                     // copy delay calib. values into status array
-            status.delay_offs[fr][stn] = (stn) ? pass->control.delay_offs[j].rem 
+            status.delay_offs[fr][stn] = (stn) ? pass->control.delay_offs[j].rem
                                                : pass->control.delay_offs[j].ref;
 
             if (param.pc_mode[stn] != MULTITONE)
@@ -127,7 +128,7 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
                         pcphas[stn][i] = pass->control.pc_phase[j][i].rem;
                     pcfreq[stn] = pass->control.pc_freq[j].rem;
                     }
-                   
+
                 for (i=0; i<2; i++)
                     {
                     status.pc_offset[fr][stn][i] = (pcphas[stn][i] != NULLFLOAT) ? pcphas[stn][i] : 0.0;
@@ -141,7 +142,7 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
                                     // expand tone #'s into frequencies, if necessary
                 if (fabs (pcfreq[stn]) > 64)
                     pcfreq_hz = 1e3 * pcfreq[stn];
-                    
+
                 else                // specified as tone #, rather than freq
                     {               // must compute frequency for this tone
                                     // assume for now that all ovex channels the same spacing
@@ -163,11 +164,11 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
                     else            // set up tone frequency for net LSB
                         {           // lsb implemented using negative frequencies
                                     // now set freq to tone # within band (1 relative)
-                        pcfreq_hz = - pcfreq_hz 
+                        pcfreq_hz = - pcfreq_hz
                                     + (pcfreq[stn] + 1) * ovex->st[n].channels[chind].pcal_spacing;
                         }
                     msg ("fcode %c freq %lf tone request %lf pc_freqhz %lf", 0,
-                          pass->pass_data[fr].freq_code, pass->pass_data[fr].frequency, 
+                          pass->pass_data[fr].freq_code, pass->pass_data[fr].frequency,
                           pcfreq[stn], pcfreq_hz);
                     }
 
@@ -175,7 +176,7 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
                     if (fabs (pcfreq_hz - pass->pass_data[fr].pc_freqs[stn][k]) < 1e-6)
                         break;
                     else
-                        msg ("pcal freq %lf didn't match", -2, 
+                        msg ("pcal freq %lf didn't match", -2,
                              pass->pass_data[fr].pc_freqs[stn][k]);
                                     // if requested frequency not available,
                                     // complain about it and use the 1st tone
@@ -200,14 +201,14 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
                                     // apply a priori phase offset to each pol
                 for (i=0; i<2; i++)
                 {
-                    status.pc_offset[fr][stn][i] = (pcphas[stn][i] != NULLFLOAT) ? pcphas[stn][i] 
+                    status.pc_offset[fr][stn][i] = (pcphas[stn][i] != NULLFLOAT) ? pcphas[stn][i]
                                                                                  : 0.0;
                                     //add the static (constant across all channels) phase offset for each pol
                     static_pc_off = (stn == 0)
-                                  ? pass->control.pc_phase_offset[i].ref 
+                                  ? pass->control.pc_phase_offset[i].ref
                                   : pass->control.pc_phase_offset[i].rem;
-                                                      
-                    status.pc_offset[fr][stn][i] += (static_pc_off != NULLFLOAT) ? static_pc_off 
+
+                    status.pc_offset[fr][stn][i] += (static_pc_off != NULLFLOAT) ? static_pc_off
                                                                                  : 0.0;
                 }
 
@@ -242,12 +243,12 @@ int precorrect (struct scan_struct* ovex, struct type_pass* pass)
                     for (k=0; k<MAX_PCF; k++)
                         if (fabs (pcfreq_hz - pass->pass_data[fr].pc_freqs[stn][k]) < 1e-6)
                             break;
-                    
+
                     if (k<MAX_PCF && (mask & 1) == 0)
                         {
                         pass->pcinband[stn][fr][nin] = k;
-                        msg ("adding pcinband[%d][%d][%d] %d pcfreq_hz %lf sb %c", 
-                              0,stn, fr, nin, pass->pcinband[stn][fr][nin], 
+                        msg ("adding pcinband[%d][%d][%d] %d pcfreq_hz %lf sb %c",
+                              0,stn, fr, nin, pass->pcinband[stn][fr][nin],
                               pcfreq_hz, ovex->st[n].channels[chind].net_sideband);
                         nin++;
                         }
